@@ -8,8 +8,7 @@ use Scalar::Util;
 
 use Carp;
 
-use Elive::Connection;
-use base qw{Elive::Connection};
+use parent qw{Elive::Connection};
 
 use Elive;
 use Elive::Util;
@@ -17,6 +16,31 @@ use Elive::Entity;
 use Elive::Entity::User;
 use Elive::Entity::ServerDetails;
 
+=head1 NAME
+
+Elive::Connection::SDK - Manage Elluminate Live SDK SOAP connections.
+
+=head1 DESCRIPTION
+
+This module handles logical connections to Elluminate I<Live!> sites.
+
+Most of the time, you won't need to use this module directly, rather
+you'll create a default connection via L<Elive>:
+
+    Elive->connect('http://someserver.com', 'someuser', 'somepass');
+
+However, if you need to manage multiple sites and/or servers. You can
+have multiple connections:
+
+    my $connection1
+            = Elive::Connection->connect('http://someserver.com/site1',
+                                        'user1' => 'pass1');
+
+    my $connection2
+            = Elive::Connection->connect('http://user2:pass2@someserver.com/site2');
+
+=cut
+
 __PACKAGE__->mk_accessors( qw{_login _server_details} );
 
 our %KnownCommands = (
@@ -87,6 +111,7 @@ our %KnownCommands = (
 	streamPreload => 'u',
 	streamRecording => 'u',
 
+	updateGroup => 'u',
 	updateMeeting => 'u',
 	updateMeetingParameters => 'u',
 	updateRecording => 'u',
@@ -116,11 +141,8 @@ connectivity and authentication details.
 sub connect {
     my ($class, $url, $user, $pass, %opt) = @_;
 
-    my $self = $class->SUPER::_connect($url, $user, $pass, %opt);
-    $self->type($opt{type} || 'SDK');
-
+    my $self = $class->_connect($url, $user, $pass, %opt);
     bless $self, $class;
-
     #
     # The login name should be a valid user in the database.
     # retrieve it as a way of authenticating the user and
@@ -196,10 +218,8 @@ SOAP::SOM object.
 
 sub call {
     my ($self, $cmd, %params) = @_;
-    $params{adapter} ||= 'default';
 
-    die "bad connection type. expected 'SDK', found: ".$self->type
-	unless $self->type eq 'SDK';
+    $params{adapter} ||= 'default';
 
     return $self->SUPER::call( $cmd, %params );
 }
@@ -284,4 +304,14 @@ sub server_details {
     return $server_details;
 }
 
+=head2 version
+
+Return the Elluminate I<Live!> Manager version
+
+=cut
+
+sub version {
+    return (my $self = shift)->server_details->version;
+}
+
 1;
