@@ -2,8 +2,7 @@ package Elive::Struct;
 use warnings; use strict;
 
 use Mouse;
-use Elive;
-use base qw{Elive};
+use parent qw{Elive};
 
 use Elive::Array;
 use Elive::Util;
@@ -56,9 +55,10 @@ In particular meeting participants stringify to userId=role, eg
 BEGIN {
     __PACKAGE__->mk_classdata('_entities' => {});
     __PACKAGE__->mk_classdata('_aliases');
+    __PACKAGE__->mk_classdata('_derivable' => {});
     __PACKAGE__->mk_classdata('_entity_name');
-    __PACKAGE__->mk_classdata('_primary_key', []);
-    __PACKAGE__->mk_classdata('_params', {});
+    __PACKAGE__->mk_classdata('_primary_key' => []);
+    __PACKAGE__->mk_classdata('_params' => {});
     __PACKAGE__->mk_classdata('collection_name');
     __PACKAGE__->mk_classdata('_isa');
 };
@@ -183,7 +183,7 @@ sub entity_name {
 
 # _alias, _get_aliases
 #
-#    MyApp::Entity::Meeting->_set_data_mapping(requiredSeats => 'seats');
+#    MyApp::Entity::Meeting->_alias(requiredSeats => 'seats');
 #
 # Return or set data mappings.
 #
@@ -224,7 +224,6 @@ sub _alias {
 }
 
 sub _get_aliases {
-
     my $entity_class = shift;
 
     my $aliases = $entity_class->_aliases;
@@ -252,7 +251,7 @@ sub id {
 
 =head2 primary_key
 
-    Setter/getter for primary key field(s) for this entity class
+Setter/getter for primary key field(s) for this entity class
 
     my @pkey = MyApp::Entity::User->primary_key
 
@@ -269,7 +268,7 @@ sub primary_key {
 
 =head2 params
 
-    Setter/getter for parameter field(s) for this entity class
+Setter/getter for parameter field(s) for this entity class
 
     Elive::Entity::User->params(loginName => 'Str');
     my %params = MyApp::Entity::User->params;
@@ -285,6 +284,21 @@ sub params {
     return %{$entity_class->_params};
 }
 
+=head2 derivable
+
+Setter/getter for derivable field(s) for this entity class
+
+=cut
+
+sub derivable {
+    my ($entity_class, %derivable) = @_;
+
+    $entity_class->_derivable(\%derivable)
+	if (keys %derivable);
+
+    return %{$entity_class->_derivable};
+}
+
 =head2 entities
 
     my $entities = Entity::Entity->entities
@@ -337,88 +351,60 @@ sub _ordered_attributes {
 }
 
 sub _cmp_col {
-    my ($class, $data_type, $_v1, $_v2, %opt) = @_;
+    my ($class, $data_type, $v1, $v2, %opt) = @_;
 
     #
     # Compare two values for a property 
     #
 
     return
-	unless (defined $_v1 && defined $_v2);
+	unless (defined $v1 && defined $v2);
 
-    my ($type, $is_array, $is_struct) = Elive::Util::parse_type($data_type);
-    my @v1 = ($is_array? @$_v1: ($_v1));
-    my @v2 = ($is_array? @$_v2: ($_v2));
-
-    my $cmp = scalar @v1 <=> scalar @v2;
-
-    unless ($cmp) {
+    my ($type, $array_type, $is_struct) = Elive::Util::parse_type($data_type);
 
+    if (!defined $v2 || !defined $v2) {
+	return;
+    }
+    elsif ($array_type || $is_struct) {
 	#
-	# unequal arrays lengths => unequal
+	# Note shallow comparision of entities and arrays.
 	#
+	my $t = $array_type || $type;
+	return $t->stringify($v1) cmp $t->stringify($v2);
+    }
 
-	if (scalar @v1 == 0) {
+    my $cmp;
 
+    if ($type =~ m{^Ref}ix) {
+	$cmp = YAML::Dump($v1) cmp YAML::Dump($v2);
+    }
+    else {
+	#
+	# Elemental comparision. Use normalised frozen values
+	#
+	$v1 = Elive::Util::_freeze($v1, $type);
+	$v2 = Elive::Util::_freeze($v2, $type);
+
+	if ($type =~ m{^(Str|Enum|HiResDate)}ix) {
 	    #
-	    # Empty arrays => equal
+	    # string comparision. works on simple strings and
+	    # stringified entities. Also used for hires dates
+	    # integer comparision may result in arithmetic overflow
 	    #
-
-	    $cmp = undef;
+	    $cmp = ($opt{case_insensitive}
+		    ? uc($v1) cmp uc($v2)
+		    : $v1 cmp $v2);
+	}
+	elsif ($type =~ m{^Bool}ix) {
+	    # boolean comparison
+	    $cmp = ($v1 eq 'true'? 1: 0) <=> ($v2 eq 'true'? 1: 0);
+	}
+	elsif ($type =~ m{^Int}ix) {
+	    # int comparision
+	    $cmp = $v1 <=> $v2;
 	}
 	else {
-	    #
-	    # arrays are of equal lengths. compare values
-	    #
-	    for (@v1, @v2) {
-		#
-		# work with normalised frozen values
-		#
-		$_ = ($is_struct       ? $type->stringify($_)
-		      : $type eq 'Ref' ? YAML::Dump($_) # no freeze method avail
-		      : Elive::Util::_freeze($_, $type));
-	    }
-
-	    if ($is_array) {
-
-		#
-		# Order of elements does not matter
-		#
-
-		@v1 = sort {$class->_cmp_col($type, $a, $b, %opt)} @v1;
-		@v2 = sort {$class->_cmp_col($type, $a, $b, %opt)} @v2;
-	    }
-
-	    for (my $i = 0; $i < @v1; $i++) {
-
-		my $v1 = $v1[$i];
-		my $v2 = $v2[$i];
-
-		if ($is_struct || $type =~ m{^(Str|Enum|HiResDate)}ix) {
-		    #
-		    # string comparision. works on simple strings and
-		    # stringified entities. Also used for hires dates
-		    # integer comparision may result in arithmetic overflow
-		    #
-		    $cmp ||= ($opt{case_insensitive}
-			      ? uc($v1) cmp uc($v2)
-			      : $v1 cmp $v2);
-		}
-		elsif ($type =~ m{^Bool}ix) {
-		    # boolean comparison
-		    $cmp ||= ($v1 eq 'true'? 1: 0) <=> ($v2 eq 'true'? 1: 0);
-		}
-		elsif ($type =~ m{^Int}ix) {
-		    # int comparision
-		    $cmp ||= $v1 <=> $v2;
-		}
-		elsif ($type =~ m{^Ref}ix) {
-		    $cmp ||= YAML::Dump($v1) cmp YAML::Dump($v2);
-		}
-		else {
-		    Carp::croak "class $class: unknown type: $type\n";
-		}
-	    }
+	    Carp::croak "class $class: unknown type: $type\n";
 	}
     }
 
@@ -452,11 +438,10 @@ Return a hashref of attribute data types.
 sub property_types {
     my $class = shift;
 
-    my $meta = $class->meta;
-    my @atts = $meta->get_attribute_list;
+    my @atts = $class->_ordered_attributes;
 
     return {
-	map {$_ => $meta->get_attribute($_)->type_constraint} @atts
+	map {$_->name => $_->type_constraint} @atts
     };
 }
 
@@ -472,8 +457,10 @@ Return a hashref of documentation for properties
 sub property_doco {
     my $class = shift;
 
+    my @atts = $class->_ordered_attributes;
+
     return {
-	map {$_->name => $_->{documentation}} ($class->_ordered_attributes)
+	map {$_->name => $_->{documentation}} @atts
     };
 }
 
@@ -491,6 +478,12 @@ sub set {
     my %entity_column = map {$_ => 1} ($self->properties);
     my %primary_key = map {$_ => 1} ($self->primary_key);
 
+    my %aliases = $self->_to_aliases;
+    for (grep {exists $data{$_}} (keys %aliases)) {
+	my $att = $aliases{$_};
+	$data{$att} = delete $data{$_};
+    }
+ 
     foreach (keys %data) {
 
 	unless ($entity_column{$_}) {
